@@ -49,8 +49,14 @@ pairs with each pair narrowing the search, sorting the results, or both,
 indicated in the following list with S<"C<[N ]>">, S<"C<[ S]>">, or "C<[NS]>",
 respectively.
 
+Supplying an array reference as a I<value> indicates a search where any of
+the values in the array are acceptable.  This does not affect sorting.
+
 The same search keys documented here are used for searching indexes, since
-C<WARC::Collection> is a wrapper around one or more indexes.
+C<WARC::Collection> is a wrapper around one or more indexes, but index
+support modules do not sort their results.  Only C<WARC::Collection> sorts
+the returned entries, so keys listed below as "sort-only" are ignored by
+the index support modules.
 
 The keys supported are:
 
@@ -164,26 +170,48 @@ sub search {
   croak "odd number of arguments given to 'search' method"
     if scalar @_ % 2;
 
-  if (scalar @{$self->{indexes}} == 1 and not wantarray)
-    # special case:  only one index to search and only one result desired
-    { my $entry = $self->{indexes}[0]->search(@_);
-      return defined $entry ? $entry->record(collection => $self) : undef }
-
-  # otherwise collect all matches from all indexes, coalesce and sort them,
-  # and return either a best match or the entire sorted list
+  # collect all matches from all indexes
   my %results = ();	# map:  tag => array of index entries for record
-  foreach my $index (@{$self->{indexes}})
-    { foreach my $entry ($index->search(@_))
-	{ push @{$results{$entry->tag}}, $entry } }
+  if (grep UNIVERSAL::isa($_, 'ARRAY'), @_) {
+    # at least one parameter is an arrayref; perform nested loop join
+    my @step = @_; my @state = (); my @varpos = ();
+    for (my $i = 1; $i <= $#step; $i += 2) {
+      next unless UNIVERSAL::isa($step[$i], 'ARRAY');
+      push @state, 0;
+      push @varpos, $i;
+      $step[$i] = $step[$i]->[0];
+    }
+    # search indexes with all combinations from the input
+    while ($state[0] <= $#{$_[$varpos[0]]}) {
+      foreach my $index (@{$self->{indexes}})
+	{ foreach my $entry ($index->search(@step))
+	    { push @{$results{$entry->tag}}, $entry } }
+    } continue {
+      # count in variable base in @state using the input arrayrefs
+      my $i = $#state;
+      $i-- while $i > 0 && $state[$i] >= $#{$_[$varpos[$i]]};
+      $step[$varpos[$i]] = $_[$varpos[$i]]->[++$state[$i]];
+      $step[$varpos[$i]] = $_[$varpos[$i]]->[$state[$i] = 0]
+	while ++$i <= $#state;
+    }
+  } else {
+    # simple case with single values; only one scan needed
+    foreach my $index (@{$self->{indexes}})
+      { foreach my $entry ($index->search(@_))
+	  { push @{$results{$entry->tag}}, $entry } }
+  }
 
+  # coalesce and sort the collected index entries
   my @results =
     map {coalesce WARC::Index::Entries ($results{$_})} keys %results;
   @results =	# sort by distance using Schwartzian transform
     (map { $_->[0] } sort { $a->[1] <=> $b->[1] }
      map { [$_, scalar $_->distance(@_)] } @results);
 
+  # return either the entire sorted list or the best match
   if (wantarray) { return map {$_->record(collection => $self)} @results }
-  else		 { return $results[0]->record(collection => $self) }
+  else		 { return (scalar @results
+			   ? $results[0]->record(collection => $self) : undef) }
 }
 
 =back
