@@ -16,6 +16,7 @@ use IO::Uncompress::Gunzip '$GunzipError';
 require WARC::Fields;
 require WARC::Record;
 require WARC::Record::Block;
+require WARC::Record::Replay;
 
 sub _set { croak "attempt to modify WARC record in file" }
 
@@ -81,6 +82,8 @@ sub _dbg_dump {
   $out .= ' [via '.$self->{compression}.']' if defined $self->{compression};
   $out .= "\n";
 
+  $out .= ' id '.$self->id."\n";
+
   $out .= ' at '.$self->offset.' in '.$self->volume."\n";
   $out .= '  "sl" header:  '.$self->{sl_packed_size}.' packed from '
     .$self->{sl_full_size}." octets\n" if defined $self->{sl_full_size};
@@ -261,7 +264,15 @@ sub open_block {
 sub open_continued { (shift)->logical->open_block }
 
 sub replay {
-  die "not yet implemented"
+  my $self = shift;
+
+  my @handlers = WARC::Record::Replay::find_handlers($self);
+
+  my $result = undef;
+  $result = (shift @handlers)->($self)
+    while scalar @handlers && !defined $result;
+
+  return $result;
 }
 
 sub open_payload {
@@ -295,7 +306,7 @@ L<WARC::Record>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2019 by Jacob Bachmeyer
+Copyright (C) 2019, 2020 by Jacob Bachmeyer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
